==> rocketmq-all-5.3.1-source-release.zip: rocketmq-all-5.3.1-source-release/container/src/main/java/org/apache/rocketmq/container/BrokerBootHook.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.rocketmq.container;

import java.util.Properties;
import org.apache.rocketmq.broker.BrokerController;

public interface BrokerBootHook {
    /**
     * Name of the hook.
     *
     * @return name of the hook
     */
    String hookName();

    /**
     * Code to execute before broker start.
     *
     * @param brokerController broker to start
     * @param properties broker properties
     * @throws Exception when execute hook
     */
    void executeBeforeStart(BrokerController brokerController, Properties properties) throws Exception;

    /**
     * Code to execute after broker start.
     *
     * @param brokerController broker to start
     * @param properties broker properties
     * @throws Exception when execute hook
     */
    void executeAfterStart(BrokerController brokerController, Properties properties) throws Exception;
}

==> rocketmq-all-5.4.0-source-release.zip: rocketmq-all-5.4.0-source-release/container/src/main/java/org/apache/rocketmq/container/BrokerBootHook.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.rocketmq.container;

import java.util.Properties;

public interface BrokerBootHook {
    /**
     * Name of the hook.
     *
     * @return name of the hook
     */
    String hookName();

    /**
     * Code to execute before broker start.
     *
     * @param innerBrokerController inner broker to start
     * @param properties broker properties
     * @throws Exception when execute hook
     */
    void executeBeforeStart(InnerBrokerController innerBrokerController, Properties properties) throws Exception;

    /**
     * Code to execute after broker start.
     *
     * @param innerBrokerController inner broker to start
     * @param properties broker properties
     * @throws Exception when execute hook
     */
    void executeAfterStart(InnerBrokerController innerBrokerController, Properties properties) throws Exception;
}
